.. :changelog:

History
-------

0.0.1 (12-04-2019)
---------------------

* First code creation


0.0.11 (28-05-2019)
-------------------

* removal of .json on set_maintenance_policy


0.0.12 (28-05-2019)
-------------------

* added functions


0.0.13 (28-05-2019)
-------------------

* maintenance policies - list functions - are now teambased


0.0.14 (28-05-2019)
-------------------

* added function: count_alerts_by_query


0.0.15 (10-06-2019)
-------------------

* 'added functionality: adding more than 1 policy to a set_maintenance_policy'


0.0.16 (10-06-2019)
-------------------

* refactoring


0.0.17 (11-06-2019)
-------------------

* 2nd try on adding multiple arguments for set_maintenance_policy


0.0.18 (09-08-2019)
-------------------

* function names with more explicit names + reusing url endpoints to make the code more dry


0.0.19 (09-08-2019)
-------------------

* Adding the functionality to enable and disable alert/notification policies


0.0.20 (16-08-2019)
-------------------

* cancel_maintenance_policy now supports multiple ID's


0.0.21 (17-08-2019)
-------------------

* Allowing the input of multiple ID's for delete_maintenance_policy


0.0.22 (18-08-2019)
-------------------

* Adding multiple arguments for: disable/enable/delete notification- & alert policy


0.0.23 (20-08-2019)
-------------------

* Small fixes regarding the loops in multiple functions


0.0.24 (07-09-2019)
-------------------

* Added the function: list_schedule_timeline_by_team_name
